/*            - io2343.h -

   This file #defines the internal register addresses for AT90S2343.
   Used with ICCA90 and AA90.
   
   Version: 1.10 [JB] 
*/

#pragma language=extended

#if (((__TID__ >> 8) & 0x7F) != 90)
#error This file should only be compiled by icca90/aa90
#endif
#if (((__TID__ >> 4) & 0x0F) != 0)
#error This file should only be included if the processor option is -v0
#endif

/* Include the SFR part if this file has not been included before,
 * OR this file is included by the assembler (SFRs must be defined in
 * each assembler module). AA90 has __TID__ bit 15 = 0. */
#if !defined(__IO2343_INCLUDED) || ((__TID__ >> 15) == 0)

/*==========================*/
/* Predefined SFR Addresses */
/*==========================*/

/* Input Pins, Port B */
sfrb PINB    = 0x16;

/* Data Direction Register, Port B */
sfrb DDRB    = 0x17;

/* Data Register, Port B */
sfrb PORTB    = 0x18;

/* EEPROM Control Register */
sfrb EECR    = 0x1C;

/* EEPROM Data Register */
sfrb EEDR    = 0x1D;

/* EEPROM Address Register Low */
sfrb EEARL   = 0x1E;          
sfrb EEAR    = 0x1E;

/* Watchdog Timer Control Register */
sfrb WDTCR    = 0x21;

/* Timer/Counter 0 */
sfrb TCNT0    = 0x32;

/* Timer/Counter 0 Control Register */
sfrb TCCR0    = 0x33;

/* MCU Status Register */
sfrb MCUSR    = 0x34;

/* MCU general Control Register */
sfrb MCUCR    = 0x35;

/* Timer/Counter Interrupt Flag register */
sfrb TIFR    = 0x38;

/* Timer/Counter Interrupt MaSK register */
sfrb TIMSK    = 0x39;

/* General Interrupt Flag register */
sfrb GIFR    = 0x3A;

/* General Interrupt MaSK register */
sfrb GIMSK    = 0x3B;

/* Stack Pointer */
sfrw SP     = 0x3D;
sfrb SPL    = 0x3D;

/* Status REGister */
sfrb SREG   = 0x3F;


#ifndef __IO2343_INCLUDED
#define __IO2343_INCLUDED

/* SFRs are local in assembler modules (so this file may need to be */
/* included in more than one module in the same source file), */
/* but #defines must only be made once per source file. */

/*==============================*/
/* Interrupt Vector Definitions */
/*==============================*/

/* NB! vectors are specified as byte addresses */

#define    RESET_vect           (0x00)
#define    INT0_vect            (0x02)
#define    TIMER0_OVF0_vect     (0x04) 
 
/* Bit definitions for use with the IAR Assembler and C compiler   
   The Register Bit names are represented by their bit number (0-7).
*/     
 
/* General Interrupt MaSK register */  
#define    INT0    6
#define    INTF0   6
 
/* General Interrupt Flag Register */                  
#define    TOIE0   1
#define    TOV0    1
 
/* MCU general Control Register */ 
#define    SE      5
#define    SM      4
#define    ISC01   1
#define    ISC00   0
 
/* Timer/Counter 0 Control Register */
#define    CS02    2
#define    CS01    1
#define    CS00    0
                        
/* Watchdog Timer Control Register */
#define    WDTOE   4
#define    WDE     3
#define    WDP2    2
#define    WDP1    1
#define    WDP0    0
 
/* EEPROM Control Register */
#define    EEMWE   2
#define    EEWE    1
#define    EERE    0
 
/* Data Register, Port B */
#define    PB4     4
#define    PB3     3
#define    PB2     2
#define    PB1     1
#define    PB0     0
 
/* Data Direction Register, Port B */
#define    DDB4    4
#define    DDB3    3
#define    DDB2    2
#define    DDB1    1
#define    DDB0    0
 
/* Input Pins, Port B */
#define    PINB4   4
#define    PINB3   3
#define    PINB2   2
#define    PINB1   1
#define    PINB0   0
       
/* Pointer definition   */ 
#define    XL     R26
#define    XH     R27
#define    YL     R28
#define    YH     R29
#define    ZL     R30
#define    ZH     R31
       
/* Contants */ 
#define    RAMEND    0xDF    ;Last On-Chip SRAM Location
#define    XRAMEND   0xDF
#define    E2END     0x7F
#define    FLASHEND  0x07FF

#endif /* __IO2343_INCLUDED (define part) */
#endif /* __IO2343_INCLUDED (SFR part) */

